@@ -5,7 +5,8 @@ import mozanalysis.metrics.desktop as mad
 import mozanalysis.metrics.fenix
 import mozanalysis.metrics.firefox_ios
 import mozanalysis.segments.desktop as msd
-from mozanalysis.experiment import AnalysisWindow, Experiment, TimeLimits
+from mozanalysis.experiment import AnalysisBasis, AnalysisWindow, Experiment, TimeLimits
+from mozanalysis.exposure import ExposureSignal
 from mozanalysis.metrics import Metric
 from mozanalysis.segments import Segment, SegmentDataSource
 
@@ -446,3 +447,83 @@ def test_firefox_ios_app_id_propagation():
     assert "my_cool_app" in enrollments_sql
 
     sql_lint(metrics_sql)
+
+
+def test_exposure_query():
+    exp = Experiment("slug", "2019-01-01", 8, app_id="my_cool_app")
+
+    tl = TimeLimits.for_ts(
+        first_enrollment_date="2019-01-01",
+        last_date_full_data="2019-03-01",
+        time_series_period="weekly",
+        num_dates_enrollment=8,
+    )
+
+    enrollment_sql = exp.build_enrollments_query(
+        time_limits=tl,
+        enrollments_query_type="glean-event",
+    )
+
+    sql_lint(enrollment_sql)
+
+    assert "exposures" in enrollment_sql
+
+
+def test_exposure_signal_query():
+    exp = Experiment("slug", "2019-01-01", 8, app_id="my_cool_app")
+
+    tl = TimeLimits.for_ts(
+        first_enrollment_date="2019-01-01",
+        last_date_full_data="2019-03-01",
+        time_series_period="weekly",
+        num_dates_enrollment=8,
+    )
+
+    enrollment_sql = exp.build_enrollments_query(
+        time_limits=tl,
+        enrollments_query_type="glean-event",
+        exposure_signal=ExposureSignal(
+            name="exposures",
+            data_source=mozanalysis.metrics.fenix.baseline,
+            select_expr="metrics.counter.events_total_uri_count > 0",
+            friendly_name="URI visited exposure",
+            description="Exposed when URI visited",
+        ),
+    )
+
+    sql_lint(enrollment_sql)
+
+    assert "exposures" in enrollment_sql
+    assert "metrics.counter.events_total_uri_count > 0" in enrollment_sql
+
+
+def test_metrics_query_based_on_exposure():
+    exp = Experiment("slug", "2019-01-01", 8)
+
+    tl = TimeLimits.for_ts(
+        first_enrollment_date="2019-01-01",
+        last_date_full_data="2019-03-01",
+        time_series_period="weekly",
+        num_dates_enrollment=8,
+    )
+
+    enrollments_sql = exp.build_enrollments_query(
+        time_limits=tl, enrollments_query_type="fenix-fallback"
+    )
+
+    sql_lint(enrollments_sql)
+
+    metrics_sql = exp.build_metrics_query(
+        metric_list=[
+            m
+            for m in mozanalysis.metrics.fenix.__dict__.values()
+            if isinstance(m, Metric)
+        ],
+        time_limits=tl,
+        enrollments_table="enrollments",
+        analysis_basis=AnalysisBasis.EXPOSURES,
+    )
+
+    sql_lint(metrics_sql)
+
+    assert "e.exposure_date" in metrics_sql
